<template>
  <ModalDialog
    ref="createModal"
    is-page
    @close="$router.push({ name: 'admin.domains' })"
  >
    <ModalHeader>
      <ModalTitle>{{ $t("app.admin.domains.create.title") }}</ModalTitle>
    </ModalHeader>
    <ModalForm @submit="submit">
      <template #default>
        <AlertError v-if="form.errors && form.errors?.unknown">
          {{ form.errors.unknown }}
        </AlertError>
        <FormInput
          id="domain"
          :errors="form.errors.domain"
        >
          <FormLabel>{{ $t("app.admin.domains.form.domain") }}</FormLabel>
          <FormText
            v-model="form.values.domain"
            name="domain"
            required
          />
        </FormInput>
        <FormInput
          id="redirect"
          :errors="form.errors.redirect"
        >
          <FormLabel>{{ $t("app.admin.domains.form.redirect") }}</FormLabel>
          <FormText
            v-model="form.values.redirect"
            name="redirect"
          />
        </FormInput>
      </template>
      <template #footer>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-black"
        >
          {{ $t("app.admin.domains.create.submit") }}
        </FormSubmit>
      </template>
    </ModalForm>
  </ModalDialog>
</template>

<script lang="ts" setup>
import ModalTitle from "@/js/contexts/shared/ui/components/modal/ModalTitle.vue";
import ModalHeader from "@/js/contexts/shared/ui/components/modal/ModalHeader.vue";
import ModalDialog from "@/js/contexts/shared/ui/components/modal/ModalDialog.vue";
import ModalForm from "@/js/contexts/shared/ui/components/modal/ModalForm.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";
import useModal from "@/js/contexts/shared/composables/useModal";
import useForm from "@/js/contexts/shared/composables/useForm";
import type { DomainCreate } from "@/js/contexts/shared/models/Domain";

const emit = defineEmits<{
  fetch: [];
}>();

const { t } = useI18n();
const { successNotification } = useNotification();
const createModal = ref<InstanceType<typeof ModalDialog>>();
const modal = useModal(createModal);
const form = useForm<DomainCreate>({
  domain: "",
  redirect: "",
});

const submit = () => {
  form.post("/api/admin/domains", {
    onSuccess: () => {
      emit("fetch");
      modal.close();
      successNotification(t("app.admin.domains.create.success"));
    },
  });
};
</script>
